# Changelog

## [1.19.0](https://github.com/vicwomg/pikaraoke/compare/1.18.4...1.19.0) (2026-03-11)


### Features

* indonesian translation (via [@funkyfone](https://github.com/funkyfone)) ([#773](https://github.com/vicwomg/pikaraoke/issues/773)) ([0846e94](https://github.com/vicwomg/pikaraoke/commit/0846e94e97b21068aa93e29776888a1d6ae80861))
* live splash preference updates, fix custom score phrases ([#784](https://github.com/vicwomg/pikaraoke/issues/784)) ([393e82b](https://github.com/vicwomg/pikaraoke/commit/393e82b866eff2dc4adb3613f25a07ff174144e6))
* option to show clock on splash screen ([#767](https://github.com/vicwomg/pikaraoke/issues/767)) ([0985978](https://github.com/vicwomg/pikaraoke/commit/098597818fe2c9d43ff5a6acd021826911b579c7))
* YouTube preview streaming and improved search result cards ([#785](https://github.com/vicwomg/pikaraoke/issues/785)) ([e49d4b8](https://github.com/vicwomg/pikaraoke/commit/e49d4b811d0be6264486194423a48504859166b7))


### Bug Fixes

* batch song renamer and prepare for centralised song editing ([#783](https://github.com/vicwomg/pikaraoke/issues/783)) ([3d9989e](https://github.com/vicwomg/pikaraoke/commit/3d9989e3f3f2f1ee6afe8126b2ab86ab88f24f65))
* browser and edit page navigation improvements ([#772](https://github.com/vicwomg/pikaraoke/issues/772)) ([61d4ca6](https://github.com/vicwomg/pikaraoke/commit/61d4ca65fd2b8928e440cce70216f7c74a80dfb8))
* centralise edit and batch song renamer functions ([#791](https://github.com/vicwomg/pikaraoke/issues/791)) ([f1fecc5](https://github.com/vicwomg/pikaraoke/commit/f1fecc5b99b8a86cc47b3165857a19814dd41b69))
* exception when opening splash screen ([#788](https://github.com/vicwomg/pikaraoke/issues/788)) ([38f2582](https://github.com/vicwomg/pikaraoke/commit/38f2582eb52d61dff1258cd0d82b90652fd556d7))
* handle .ass subtitle files in delete and rename operations ([#769](https://github.com/vicwomg/pikaraoke/issues/769)) ([e476c40](https://github.com/vicwomg/pikaraoke/commit/e476c40f44ade0daaf807c62539c36e6220cc8eb))
* prevent direct download from downloading playlists ([#766](https://github.com/vicwomg/pikaraoke/issues/766)) ([38f38f8](https://github.com/vicwomg/pikaraoke/commit/38f38f88fb78a986d1c878ce9252834f05876d41))
* support multiple sections in the config file ([#776](https://github.com/vicwomg/pikaraoke/issues/776)) ([f08b766](https://github.com/vicwomg/pikaraoke/commit/f08b766733fcf5654ebe8dd4e180223132cc7b19))
* update yt-dlp to 2026.02.21 ([#789](https://github.com/vicwomg/pikaraoke/issues/789)) ([66e365e](https://github.com/vicwomg/pikaraoke/commit/66e365e9545c5b1c385fb6606e0a92760bdf146f))
* upgrade yt-dlp to 2026.03.03 ([#798](https://github.com/vicwomg/pikaraoke/issues/798)) ([ee7cf31](https://github.com/vicwomg/pikaraoke/commit/ee7cf3164b04666c7467f584a82996f36f5dd437))
* use os.path.join for download path instead of trailing slash hack ([#770](https://github.com/vicwomg/pikaraoke/issues/770)) ([ee1ce2f](https://github.com/vicwomg/pikaraoke/commit/ee1ce2f6c010d948f690991abe8f7d36e7bb8f9a))

## [1.18.4](https://github.com/vicwomg/pikaraoke/compare/1.18.3...1.18.4) (2026-02-09)


### Bug Fixes

* docker yt-dlp upgrade fails, bump yt-dlp version ([#764](https://github.com/vicwomg/pikaraoke/issues/764)) ([b2d3d9b](https://github.com/vicwomg/pikaraoke/commit/b2d3d9bf122e393a49e3578f903324d4aac13673))
* installation on windows to include C++ distributable ([#763](https://github.com/vicwomg/pikaraoke/issues/763)) ([a02f14f](https://github.com/vicwomg/pikaraoke/commit/a02f14fc45d8ee349544f78becd90c9f4a97db58))

## [1.18.3](https://github.com/vicwomg/pikaraoke/compare/1.18.2...1.18.3) (2026-02-03)


### Bug Fixes

* correctly allow or block editing of files ([#742](https://github.com/vicwomg/pikaraoke/issues/742)) ([385dffb](https://github.com/vicwomg/pikaraoke/commit/385dffb4f4222c3f086adf34d135ef527ce7b19c))
* Menu icon doesn't auto-hide on some browsers ([#744](https://github.com/vicwomg/pikaraoke/issues/744)) ([ada0d0c](https://github.com/vicwomg/pikaraoke/commit/ada0d0cd354f3fb61fee218083c1195d4f7dc6a4))
* **splash:** add CJK/Cyrillic/Thai subtitle support ([#750](https://github.com/vicwomg/pikaraoke/issues/750)) ([ba116f1](https://github.com/vicwomg/pikaraoke/commit/ba116f18cfac8227e8cff8b52043e7966141bff7)), closes [#748](https://github.com/vicwomg/pikaraoke/issues/748)
* **splash:** start screensaver idle timer on initialization ([#749](https://github.com/vicwomg/pikaraoke/issues/749)) ([c275bfa](https://github.com/vicwomg/pikaraoke/commit/c275bfad565c3b399a04aef7ee25fb7bc1c2841c))
* upgrade yt-dlp to 2026.1.31 ([#752](https://github.com/vicwomg/pikaraoke/issues/752)) ([9db210a](https://github.com/vicwomg/pikaraoke/commit/9db210a120f07c2d5cc8e209905c30bbe0de9b15))


### Performance Improvements

* improve docker build speed, image size, and add smoke test ([#741](https://github.com/vicwomg/pikaraoke/issues/741)) ([b5450b5](https://github.com/vicwomg/pikaraoke/commit/b5450b5f198cdab8be8f1131017528d959bb18b5))
* remove python handling from installer, uv takes care of it ([#740](https://github.com/vicwomg/pikaraoke/issues/740)) ([e605368](https://github.com/vicwomg/pikaraoke/commit/e605368e610ee1f364e0506447556c2c144227b1))


### Documentation

* **translation:** update translation files ([#754](https://github.com/vicwomg/pikaraoke/issues/754)) ([c42bcdc](https://github.com/vicwomg/pikaraoke/commit/c42bcdc633168afa87e52af6facb62cc5772ffe7))

## [1.18.2](https://github.com/vicwomg/pikaraoke/compare/1.18.1...1.18.2) (2026-01-30)


### Bug Fixes

* download status, edit song not working ([#736](https://github.com/vicwomg/pikaraoke/issues/736)) ([d8ef52c](https://github.com/vicwomg/pikaraoke/commit/d8ef52ca18ed5fbcefc4d9789a6a24ab8617079e))
* relative logo paths don't work ([#738](https://github.com/vicwomg/pikaraoke/issues/738)) ([80dbb04](https://github.com/vicwomg/pikaraoke/commit/80dbb0484096d3b32b52b3fedc6752db03b021d5))


### Documentation

* much-needed readme / github pages / logo refresh ([#733](https://github.com/vicwomg/pikaraoke/issues/733)) ([338742e](https://github.com/vicwomg/pikaraoke/commit/338742e186c1b892dcf7442e1cd544d2a05736fb))

## [1.18.1](https://github.com/vicwomg/pikaraoke/compare/1.18.0...1.18.1) (2026-01-30)


### Bug Fixes

* apply correct scaling to screen saver and subtitles ([#724](https://github.com/vicwomg/pikaraoke/issues/724)) ([2bf2048](https://github.com/vicwomg/pikaraoke/commit/2bf204866f5145a95287662fc79f385b66995ec4))
* bg music setting also disables bg video, add bg music disable setting to UI ([#731](https://github.com/vicwomg/pikaraoke/issues/731)) ([6e6a2bb](https://github.com/vicwomg/pikaraoke/commit/6e6a2bb7e1bf665d50e933a716b6e6d7f2c7e41f))
* OSX installer installs ffmpeg that cannot transpose ([#723](https://github.com/vicwomg/pikaraoke/issues/723)) ([9ae4b9f](https://github.com/vicwomg/pikaraoke/commit/9ae4b9f18aa9baaef5b0418c2d31ff81e0e57e22))
* some browsers flash an ugly grey screen before video starts ([#730](https://github.com/vicwomg/pikaraoke/issues/730)) ([fd2fc4e](https://github.com/vicwomg/pikaraoke/commit/fd2fc4eb59133595bb02d4ee91901b3de66c9a3f))
* yt-dlp update to 2026.1.29 ([#729](https://github.com/vicwomg/pikaraoke/issues/729)) ([64895b3](https://github.com/vicwomg/pikaraoke/commit/64895b3b9c241d2ca4f6e5420c1a995c9282b994))


### Performance Improvements

* use uv tool for installs, improve smoke tests ([#726](https://github.com/vicwomg/pikaraoke/issues/726)) ([c790e9f](https://github.com/vicwomg/pikaraoke/commit/c790e9f61c807119acf0e516585aa6b6e8793736))

## [1.18.0](https://github.com/vicwomg/pikaraoke/compare/1.17.2...1.18.0) (2026-01-28)


### Features

* add tests for queue socketio and regression ([#711](https://github.com/vicwomg/pikaraoke/issues/711)) ([40449f4](https://github.com/vicwomg/pikaraoke/commit/40449f4301326fc2478ed41879c25804d2e7041c))
* centralise background media handling ([#710](https://github.com/vicwomg/pikaraoke/issues/710)) ([a18c4d7](https://github.com/vicwomg/pikaraoke/commit/a18c4d7606ff185dcfaee04dac26303d5557fd5a))
* multiple splash screen synchronization and master/slave modes ([#708](https://github.com/vicwomg/pikaraoke/issues/708)) ([e71e044](https://github.com/vicwomg/pikaraoke/commit/e71e044b21a152bce26877668bdd629f93475234))
* one-liner pikaraoke install scripts [#713](https://github.com/vicwomg/pikaraoke/issues/713) ([#714](https://github.com/vicwomg/pikaraoke/issues/714)) ([25d51e3](https://github.com/vicwomg/pikaraoke/commit/25d51e314987b12c3be25ab80d2b6839b706849f))
* splash screen url scaling ([#715](https://github.com/vicwomg/pikaraoke/issues/715)) ([a04e6a2](https://github.com/vicwomg/pikaraoke/commit/a04e6a2998f8c62ac9c9905dd771277d299b1c0b))
* update docker files to reflect app data directory ([#709](https://github.com/vicwomg/pikaraoke/issues/709)) ([9ec6d72](https://github.com/vicwomg/pikaraoke/commit/9ec6d72687e8905ee94b786eeecdbb68574a402b))
* yt-dlp simplify install and launch versions, enable async updates  ([#718](https://github.com/vicwomg/pikaraoke/issues/718)) ([96f23e8](https://github.com/vicwomg/pikaraoke/commit/96f23e89d433c9cdf4cbf433917ada9554a2d3eb))


### Bug Fixes

* incorrect install script URLs ([#716](https://github.com/vicwomg/pikaraoke/issues/716)) ([109a918](https://github.com/vicwomg/pikaraoke/commit/109a918cb8f363d2a36c837cfbcd21dbe2992ab7))

## [1.17.2](https://github.com/vicwomg/pikaraoke/compare/1.17.1...1.17.2) (2026-01-22)


### Bug Fixes

* download + queue broken on windows for songs with special chars ([#702](https://github.com/vicwomg/pikaraoke/issues/702)) ([f399b57](https://github.com/vicwomg/pikaraoke/commit/f399b5773476eb19acddfb3197f30cb386227445))
* splash up next does not update on new queue reorder actions ([#701](https://github.com/vicwomg/pikaraoke/issues/701)) ([7b3909a](https://github.com/vicwomg/pikaraoke/commit/7b3909a8a2270b43b7773dec878de05f4f227c0e))

## [1.17.1](https://github.com/vicwomg/pikaraoke/compare/1.17.0...1.17.1) (2026-01-20)


### Bug Fixes

* bad merge deleted download status feature ([#690](https://github.com/vicwomg/pikaraoke/issues/690)) ([b57962d](https://github.com/vicwomg/pikaraoke/commit/b57962de30e37042e1f38be9cf3fc1af6c357f85))
* improve logging: yt-dlp upgrades and pikaraoke version ([#693](https://github.com/vicwomg/pikaraoke/issues/693)) ([3854a4f](https://github.com/vicwomg/pikaraoke/commit/3854a4f57578c8f0477691d35baebde94c5f8290))

## [1.17.0](https://github.com/vicwomg/pikaraoke/compare/1.16.0...1.17.0) (2026-01-19)


### Features

* drag+drop queue reordering, move to top/bottom ([#676](https://github.com/vicwomg/pikaraoke/issues/676)) ([944447a](https://github.com/vicwomg/pikaraoke/commit/944447abecb02c7b2e3d65ef011ce0e06ed77254))
* fix logging import for file_resolver ([#675](https://github.com/vicwomg/pikaraoke/issues/675)) ([039fedb](https://github.com/vicwomg/pikaraoke/commit/039fedb326e4a70fe33bdfb7fea762c6bce9d3e4))
* Refactor file storage to use platform-specific data directories ([#643](https://github.com/vicwomg/pikaraoke/issues/643)) ([bcd4c52](https://github.com/vicwomg/pikaraoke/commit/bcd4c526710573421896b48b8aea9d79cb28fd55))
* Replace Selenium with direct browser subprocess launching ([#670](https://github.com/vicwomg/pikaraoke/issues/670)) ([ac70a27](https://github.com/vicwomg/pikaraoke/commit/ac70a271f4fa519f801bb08c6e5918796224b999))
* show download queue with realtime progress bar ([#661](https://github.com/vicwomg/pikaraoke/issues/661)) ([233eb4a](https://github.com/vicwomg/pikaraoke/commit/233eb4a3b3ea17201e8bd8c3ff8849f2f5265e80))
* Smart Queue (Round-Robin Fair Play) ([#677](https://github.com/vicwomg/pikaraoke/issues/677)) ([239b530](https://github.com/vicwomg/pikaraoke/commit/239b53042bebdea77d8d8ad1cbf68b4785e30ff3))
* Update dependencies ([#679](https://github.com/vicwomg/pikaraoke/issues/679)) ([7c102d0](https://github.com/vicwomg/pikaraoke/commit/7c102d0b6beb179b1dd6700319c140b00cd01c85))


### Bug Fixes

* api-docs job failing ([#647](https://github.com/vicwomg/pikaraoke/issues/647)) ([163e59f](https://github.com/vicwomg/pikaraoke/commit/163e59f68ad5ec7b5f12fc2134c8dcee44f619b3))
* autoplay detection test positive, mobile layout issue ([#688](https://github.com/vicwomg/pikaraoke/issues/688)) ([4836cbe](https://github.com/vicwomg/pikaraoke/commit/4836cbe7c689088be6229657bd9b9f6eb8f659b1))
* delete file not working since upgrade to SPA architecture ([#673](https://github.com/vicwomg/pikaraoke/issues/673)) ([ecdc730](https://github.com/vicwomg/pikaraoke/commit/ecdc73034bcb14e1afee8660166bb4f3da995594))
* Docker entrypoint args not separated properly ([#678](https://github.com/vicwomg/pikaraoke/issues/678)) ([ba9d12b](https://github.com/vicwomg/pikaraoke/commit/ba9d12b170011513066d141b79619bde9ccdaada))
* flasgger incompatibilities, disable by default ([#646](https://github.com/vicwomg/pikaraoke/issues/646)) ([452b847](https://github.com/vicwomg/pikaraoke/commit/452b847a7129f4e0372d1daa4d83dea8151bc500))
* gitignore for Claude local directory ([#663](https://github.com/vicwomg/pikaraoke/issues/663)) ([0b16065](https://github.com/vicwomg/pikaraoke/commit/0b16065bef07d924eec6848248960da78d99b426))
* Growing request URL when browsing pages of songs ([#644](https://github.com/vicwomg/pikaraoke/issues/644)) ([0025fb8](https://github.com/vicwomg/pikaraoke/commit/0025fb888d4fc266e694ce513a8c2435fe1e921f))
* hide chrome warnings unless log level debug ([#649](https://github.com/vicwomg/pikaraoke/issues/649)) ([62fb1e6](https://github.com/vicwomg/pikaraoke/commit/62fb1e6ad7a3f8c2364f43f0a114fdfc29c52baa))
* make sure title renders correctly on splash page ([#671](https://github.com/vicwomg/pikaraoke/issues/671)) ([69aa7d2](https://github.com/vicwomg/pikaraoke/commit/69aa7d2206b8d1951b2ca5183f0a8c45ce45a5ed))
* prevent autoplay race condition and improve autoplay detection ([#682](https://github.com/vicwomg/pikaraoke/issues/682)) ([06ea6f1](https://github.com/vicwomg/pikaraoke/commit/06ea6f1875cb4eef41b49d23c92afa2b3522f30a))
* race conditions on slow hardware causing playback failure ([#680](https://github.com/vicwomg/pikaraoke/issues/680)) ([9abc0dd](https://github.com/vicwomg/pikaraoke/commit/9abc0ddcd7ae728a0a400ba4099484e0847fad7c))
* slow info.html page load due to CPU check ([#659](https://github.com/vicwomg/pikaraoke/issues/659)) ([f98172f](https://github.com/vicwomg/pikaraoke/commit/f98172fcefd3f1e38e7c36c4579bc38f49398cfd))
* Splash Page ?confirm=false not working  ([#658](https://github.com/vicwomg/pikaraoke/issues/658)) ([ef99671](https://github.com/vicwomg/pikaraoke/commit/ef9967113a678deb58619d2e96cf9565ce3d7e11))
* Use absolute paths for .ass, bg video and bg audio ([#652](https://github.com/vicwomg/pikaraoke/issues/652)) ([d65aab9](https://github.com/vicwomg/pikaraoke/commit/d65aab91313687e1750252cc9a5164fb42521788))
* use flasgger stable version for compatibility ([#668](https://github.com/vicwomg/pikaraoke/issues/668)) ([da9b9be](https://github.com/vicwomg/pikaraoke/commit/da9b9bed3d0d55fa842287de1465a8452d96fc54))


### Documentation

* Add Claude Code guidance ([#655](https://github.com/vicwomg/pikaraoke/issues/655)) ([9c566bc](https://github.com/vicwomg/pikaraoke/commit/9c566bc56f1d85b930a581eff78e826d3ed5f7bd))
* update readme to remove reference to chromedriver ([#683](https://github.com/vicwomg/pikaraoke/issues/683)) ([bfab3dd](https://github.com/vicwomg/pikaraoke/commit/bfab3dd3914cd5468c04c3d2c78166ecca18ecbb))

## [1.16.0](https://github.com/vicwomg/pikaraoke/compare/1.15.3...1.16.0) (2026-01-05)


### Features

* collapsable submenus in settings area, style tweaks ([#634](https://github.com/vicwomg/pikaraoke/issues/634)) ([9ecb6af](https://github.com/vicwomg/pikaraoke/commit/9ecb6af1771471667edb3ffb8710ab072208f48f))
* launch on external display with: --external-monitor ([#624](https://github.com/vicwomg/pikaraoke/issues/624)) ([c2ff91d](https://github.com/vicwomg/pikaraoke/commit/c2ff91d7ca1254fc8672871b4757ecbf458fe21f))
* optimize web UIs with SPA architecture, add --browse-results-per-page CLI parameter ([#619](https://github.com/vicwomg/pikaraoke/issues/619)) ([c12bee0](https://github.com/vicwomg/pikaraoke/commit/c12bee0d2764458853ff656b5ee35a75c05207d1))
* support Aegisub subtitle format (thanks [@italozaina](https://github.com/italozaina)) ([#635](https://github.com/vicwomg/pikaraoke/issues/635)) ([1254091](https://github.com/vicwomg/pikaraoke/commit/1254091ba6e45b3c5c95953703e625d29504d593))


### Bug Fixes

* shutdown/restart buttons don't show in settings screen for raspberry pi ([#633](https://github.com/vicwomg/pikaraoke/issues/633)) ([2854369](https://github.com/vicwomg/pikaraoke/commit/2854369320256b11989f022e640dbe6ee9623fac))

## [1.15.3](https://github.com/vicwomg/pikaraoke/compare/1.15.2...1.15.3) (2026-01-04)


### Bug Fixes

* restore broken release workflow, optimize smoke test ([#629](https://github.com/vicwomg/pikaraoke/issues/629)) ([0ffc6b4](https://github.com/vicwomg/pikaraoke/commit/0ffc6b42bd1a5d933b63e8afb4f6ea8db4b0685e))

## [1.15.2](https://github.com/vicwomg/pikaraoke/compare/1.15.1...1.15.2) (2026-01-04)


### Bug Fixes

* hq video downloads stopped working [#625](https://github.com/vicwomg/pikaraoke/issues/625) ([#626](https://github.com/vicwomg/pikaraoke/issues/626)) ([9cd49d2](https://github.com/vicwomg/pikaraoke/commit/9cd49d21e0e1f98d8c6633783f03b1412fed96ef))

## [1.15.1](https://github.com/vicwomg/pikaraoke/compare/1.15.0...1.15.1) (2026-01-04)


### Bug Fixes

* repair broken translations ([#620](https://github.com/vicwomg/pikaraoke/issues/620)) ([d9e2eb3](https://github.com/vicwomg/pikaraoke/commit/d9e2eb3cc1e69b6ad8e49ce7b96daafc54b3b390))
* settings persistence / broken typecasting ([#621](https://github.com/vicwomg/pikaraoke/issues/621)) ([29fa3aa](https://github.com/vicwomg/pikaraoke/commit/29fa3aa43f10c0868a97e8ccc8145d87361168d7))

## [1.15.0](https://github.com/vicwomg/pikaraoke/compare/1.14.3...1.15.0) (2026-01-03)


### Features

* enable setting preferred language via CLI [#549](https://github.com/vicwomg/pikaraoke/issues/549) ([#593](https://github.com/vicwomg/pikaraoke/issues/593)) ([e6afe96](https://github.com/vicwomg/pikaraoke/commit/e6afe961283baf9f1196fc45103815d712054ed5))
* implement HLS streaming option, optimize for pi3 ([#598](https://github.com/vicwomg/pikaraoke/issues/598)) ([f1e54b3](https://github.com/vicwomg/pikaraoke/commit/f1e54b388c0c016b7f7ed591063b856b56b9c1d2))
* serialize/queue downloads from yt-dlp ([#601](https://github.com/vicwomg/pikaraoke/issues/601)) ([5a2d46b](https://github.com/vicwomg/pikaraoke/commit/5a2d46bdfb0fb4e124ca884a224a7573b6e1b074))


### Bug Fixes

* config boolean preferences set to False are ignored ([#609](https://github.com/vicwomg/pikaraoke/issues/609)) ([2930401](https://github.com/vicwomg/pikaraoke/commit/29304011bf83afc3da2c96256ac5ddb45f1cee0b))
* improve ip detection x-platform with psutil ([#616](https://github.com/vicwomg/pikaraoke/issues/616)) ([0de3455](https://github.com/vicwomg/pikaraoke/commit/0de34558f0b9307dc035fdf523301941e6cf3597))
* improve windows ip/chromedriver detection ([#610](https://github.com/vicwomg/pikaraoke/issues/610)) ([4dd9509](https://github.com/vicwomg/pikaraoke/commit/4dd9509009634d8a08349ec60d83bd31a5f42aa4))
* splash screen menu loads page twice ([#614](https://github.com/vicwomg/pikaraoke/issues/614)) ([b19abd8](https://github.com/vicwomg/pikaraoke/commit/b19abd86cbec89e7fc90c725899900169e39af75))
* use hls.js on mobile safari for better stability ([#604](https://github.com/vicwomg/pikaraoke/issues/604)) ([bd8bb9c](https://github.com/vicwomg/pikaraoke/commit/bd8bb9c48b9cf98289d0b8449d360b9ba53dd096))


### Performance Improvements

* hls_playlist_type=event for progressive HLS streaming ([#608](https://github.com/vicwomg/pikaraoke/issues/608)) ([5a3239a](https://github.com/vicwomg/pikaraoke/commit/5a3239a4717904ad7365460a3bdd911885020578))
* optimize song list editing ([#613](https://github.com/vicwomg/pikaraoke/issues/613)) ([4727550](https://github.com/vicwomg/pikaraoke/commit/4727550365a687e7b3986d27ec47a5a25c985e35))


### Documentation

* update readme with current chromium install cmds ([ed418d6](https://github.com/vicwomg/pikaraoke/commit/ed418d6a3e434a5d9fe961a091c3bdac7e0946be))

## [1.14.3](https://github.com/vicwomg/pikaraoke/compare/1.14.2...1.14.3) (2025-12-24)


### Bug Fixes

* superficial commit to fix build ([225e2fc](https://github.com/vicwomg/pikaraoke/commit/225e2fc824d1456c86427b97107c383052a0d309))

## [1.14.2](https://github.com/vicwomg/pikaraoke/compare/1.14.1...1.14.2) (2025-12-23)

### Features

- Styling refresh to latest bulma https://github.com/vicwomg/pikaraoke/commit/405dc4fef17d2d88ac41fd6ec940383c8f422139
- Updated settings page https://github.com/vicwomg/pikaraoke/commit/405dc4fef17d2d88ac41fd6ec940383c8f422139
- Edit performance rating from settings page https://github.com/vicwomg/pikaraoke/commit/405dc4fef17d2d88ac41fd6ec940383c8f422139
- Bulk song name editor https://github.com/vicwomg/pikaraoke/commit/405dc4fef17d2d88ac41fd6ec940383c8f422139
- Added a default value for the YouTube field to improve user experience. https://github.com/vicwomg/pikaraoke/commit/405dc4fef17d2d88ac41fd6ec940383c8f422139
- Clicking on the video thumbnail now opens a modal allowing users to preview the video. https://github.com/vicwomg/pikaraoke/commit/405dc4fef17d2d88ac41fd6ec940383c8f422139

### Bug Fixes

- update api docs job failing ([3bad488](https://github.com/vicwomg/pikaraoke/commit/3bad488e3b929b1afd30d43f6c87ffffafd75ca8))
- Fix mic icon not showing on splash screen https://github.com/vicwomg/pikaraoke/commit/405dc4fef17d2d88ac41fd6ec940383c8f422139
- Clear button — when the user selected a song and clicked the clear button, the input field was not being cleared. https://github.com/vicwomg/pikaraoke/commit/405dc4fef17d2d88ac41fd6ec940383c8f422139
- "Search/Add to queue" button — when the user typed something and then deleted all text, the button was incorrectly switching to "Add to queue". https://github.com/vicwomg/pikaraoke/commit/405dc4fef17d2d88ac41fd6ec940383c8f422139

### Documentation

- api docs and python project modernization ([d709de32](https://github.com/vicwomg/pikaraoke/commit/d709de328b37d044fb463137847a45ea902476e1))

## [1.14.1](https://github.com/vicwomg/pikaraoke/compare/1.14.0...1.14.1) (2025-11-27)

### Bug Fixes

- Update yt-dlp to 2025.11.12, add js runtime support ([#541](https://github.com/vicwomg/pikaraoke/issues/541)) ([#553](https://github.com/vicwomg/pikaraoke/issues/553)) ([127c22b](https://github.com/vicwomg/pikaraoke/commit/127c22be12e6db1fc03e338773d07bd2be995585))

### Documentation

- recommend [@lvmasterrj](https://github.com/lvmasterrj) windows install script ([d5bcab7](https://github.com/vicwomg/pikaraoke/commit/d5bcab79e4d754b1d65fcafa0b9cd77418c29f2b))

## [1.14.0](https://github.com/vicwomg/pikaraoke/compare/1.13.0...1.14.0) (2025-11-11)

### Features

- allow specifying yt-dlp args in CLI [#537](https://github.com/vicwomg/pikaraoke/issues/537) ([09cf7e8](https://github.com/vicwomg/pikaraoke/commit/09cf7e85e29518c06148aba9ceafbc50f449db29))
- persist "non-karaoke" checkbox state [#536](https://github.com/vicwomg/pikaraoke/issues/536) ([b1a2732](https://github.com/vicwomg/pikaraoke/commit/b1a2732fa1b9c0d32a5937d1c9c6158a2a0780a5))
- prefer h264 codec for youtube download ([#535](https://github.com/vicwomg/pikaraoke/issues/535)) ([38f3dc9](https://github.com/vicwomg/pikaraoke/commit/38f3dc96eed6714cae4f935cbed3d3d5379b74b8))
- russian translation from [@avlubimov](https://github.com/avlubimov) ([6ed5e27](https://github.com/vicwomg/pikaraoke/commit/6ed5e2700b9d5231c812f7b8fe2f24b6fdb29d67))

### Bug Fixes

- unidecode breaks search, add pycharm to gitignore ([#540](https://github.com/vicwomg/pikaraoke/issues/540)) ([467c65d](https://github.com/vicwomg/pikaraoke/commit/467c65d67910ecd2828a64b0c3592a6a2c1c2ddf))

## [1.13.0](https://github.com/vicwomg/pikaraoke/compare/1.12.0...1.13.0) (2025-08-02)

### Features

- Upscale CDG using nearest neigbor algorithm [#511](https://github.com/vicwomg/pikaraoke/issues/511) ([4326f66](https://github.com/vicwomg/pikaraoke/commit/4326f6676cdd8c67933058224cb594247c77fe41))

### Bug Fixes

- error launching on pi: iwconfig is not found [#510](https://github.com/vicwomg/pikaraoke/issues/510) ([b329664](https://github.com/vicwomg/pikaraoke/commit/b3296645dea96d9b668527c976ac293b3789ff6f))
- proxy error "not an accepted origin" [#519](https://github.com/vicwomg/pikaraoke/issues/519) ([#523](https://github.com/vicwomg/pikaraoke/issues/523)) ([c7a90cf](https://github.com/vicwomg/pikaraoke/commit/c7a90cf6e49613284217f969f54122bea65abff9))
- settings checkbox show incorrect state when False ([18e5751](https://github.com/vicwomg/pikaraoke/commit/18e5751eebc564f7d5b919a373b3b4e22873c1dd))
- update outdated translation files ([4dc5432](https://github.com/vicwomg/pikaraoke/commit/4dc5432144892e1efd02e8b38c8fbc6afecc17c2))

### Documentation

- update translation files ([3836d17](https://github.com/vicwomg/pikaraoke/commit/3836d17e1878e56ad06dadd63ed9c0d418c4e0f3))

## [1.12.0](https://github.com/vicwomg/pikaraoke/compare/1.11.1...1.12.0) (2025-07-31)

### Features

- update VE spanish translation 2025 ([#518](https://github.com/vicwomg/pikaraoke/issues/518)) ([50c2411](https://github.com/vicwomg/pikaraoke/commit/50c24115555fd8ab65ac9189542a4ff57333ffd5))
- ZH_TW i18n support and language change UI ([#517](https://github.com/vicwomg/pikaraoke/issues/517)) ([271b426](https://github.com/vicwomg/pikaraoke/commit/271b426a60b89150602827da72d0c50d88bfacfb))

### Bug Fixes

- code quality issues ([af29ecf](https://github.com/vicwomg/pikaraoke/commit/af29ecf630940521bb9b6e9c0bc2e2facfbae816))
- relax yml lint requirements ([22b5335](https://github.com/vicwomg/pikaraoke/commit/22b53351da892ef46f0b7f90df17470e39cfd61b))

## [1.11.1](https://github.com/vicwomg/pikaraoke/compare/1.11.0...1.11.1) (2025-04-26)

### Bug Fixes

- fix merge conflict ([d35ee93](https://github.com/vicwomg/pikaraoke/commit/d35ee93ed286392e92c82984def99ad97d703d81))

### Documentation

- Add correct dockerhub URL ([757b65b](https://github.com/vicwomg/pikaraoke/commit/757b65b1c8ec259844e7d3dfe445099eb27dbd0b))
- add french translation ([#505](https://github.com/vicwomg/pikaraoke/issues/505)) ([d55fbdf](https://github.com/vicwomg/pikaraoke/commit/d55fbdf46c13f58120b4a774c5cab2a8f4306b7b))
- add Italian translation ([26dc459](https://github.com/vicwomg/pikaraoke/commit/26dc459bff15fce3020a5f6e9fbb8f51c2bc4fea))
- fix translation errors ([aa8aff7](https://github.com/vicwomg/pikaraoke/commit/aa8aff77320dbafd99defcbc871880209f2cfbb7))

## [1.11.0](https://github.com/vicwomg/pikaraoke/compare/1.10.3...1.11.0) (2025-02-08)

### Features

- add support for adjusting a/v sync ([#489](https://github.com/vicwomg/pikaraoke/issues/489)) ([489d2ef](https://github.com/vicwomg/pikaraoke/commit/489d2ef214b2951bb2373cedca1ee5db3b0277ba))

### Bug Fixes

- high quality video flag state not displaying in info.html ([3bc7719](https://github.com/vicwomg/pikaraoke/commit/3bc7719397902070073256aa9efff7dd989eb1ca))
- installed eventlet python package prevents launch ([99496cd](https://github.com/vicwomg/pikaraoke/commit/99496cdc643530fc45c7e75b5855e31a3d8b80e3))

### Documentation

- PT-BR translation for Pikaraoke ([455c528](https://github.com/vicwomg/pikaraoke/commit/455c528526ebe786d974d62c8249b428d34159b0))

## [1.10.3](https://github.com/vicwomg/pikaraoke/compare/1.10.2...1.10.3) (2025-01-21)

### Bug Fixes

- confirmation override breaks video playback ([a372d52](https://github.com/vicwomg/pikaraoke/commit/a372d520a5b70c079d2c012952e61ed1f5c9da45))

## [1.10.2](https://github.com/vicwomg/pikaraoke/compare/1.10.1...1.10.2) (2025-01-21)

### Bug Fixes

- Add German translation ([70a9557](https://github.com/vicwomg/pikaraoke/commit/70a95576d6e8e881e1a5afd226142a169044304d))

## [1.10.1](https://github.com/vicwomg/pikaraoke/compare/1.10.0...1.10.1) (2025-01-14)

### Bug Fixes

- Docker build not working in CI ([cd3d9ae](https://github.com/vicwomg/pikaraoke/commit/cd3d9ae3ad7b0fa9426744e118a73055869b2670))

### Documentation

- add additional language templates: NO, RU, TH ([a3c447f](https://github.com/vicwomg/pikaraoke/commit/a3c447fec588cf3c1b57eb06e87bf4d5755fae29))
- update readme for clarity and brevity ([2bfa77f](https://github.com/vicwomg/pikaraoke/commit/2bfa77fc0ea8ca4f1d8dbb5a3c8310bc732cd47a))

## [1.10.0](https://github.com/vicwomg/pikaraoke/compare/1.9.0...1.10.0) (2025-01-14)

### Features

- add placeholder translation files for common languages ([30c9d5b](https://github.com/vicwomg/pikaraoke/commit/30c9d5ba791a577ea7333bec48625f71b2245c7c))
- support for specifying yt-dlp proxy ([e276fbf](https://github.com/vicwomg/pikaraoke/commit/e276fbfe1ae3b7495fe7750bdcb15bd948c7eb72))

### Performance Improvements

- use websocket for player communication ([#466](https://github.com/vicwomg/pikaraoke/issues/466)) ([bbd0360](https://github.com/vicwomg/pikaraoke/commit/bbd036073ef456cdb4e213161cdccea51065b7c5))

## [1.9.0](https://github.com/vicwomg/pikaraoke/compare/1.8.0...1.9.0) (2025-01-08)

### Features

- support splash screen background video ([#464](https://github.com/vicwomg/pikaraoke/issues/464)) ([5774208](https://github.com/vicwomg/pikaraoke/commit/5774208b95ff8530f564ae62c52af69eba4e65bf))

### Bug Fixes

- allow mp4 files in create_random_playlist, add max_songs param ([5c2db91](https://github.com/vicwomg/pikaraoke/commit/5c2db915dc2a72dde93fd2c9f922b598a2a7e027))
- missing delayed halt function ([9cf7ab8](https://github.com/vicwomg/pikaraoke/commit/9cf7ab87e9a67d5a042cc2f97f48e9b789f39ba5))
- tmp directory is not writeable in android [#549](https://github.com/vicwomg/pikaraoke/issues/549) ([b06367b](https://github.com/vicwomg/pikaraoke/commit/b06367b69d7a0dace7c9555f46353028bacb4cd1))
- volume_change logging error, remove logging in bg_playlist ([147364c](https://github.com/vicwomg/pikaraoke/commit/147364cb59c48623e25f02f83e24fe1401692f53))

## [1.8.0](https://github.com/vicwomg/pikaraoke/compare/1.7.0...1.8.0) (2025-01-03)

### Features

- add more user preferences to info screen ([39fb27b](https://github.com/vicwomg/pikaraoke/commit/39fb27ba844c860ada8dd2b92cb5e0a852f39860))
- add parameter for full buffering approach ([dd9dba6](https://github.com/vicwomg/pikaraoke/commit/dd9dba61ed8d83c3d40c7c0dda24cc11bba832d5))
- add timestamp to splash screen ([#452](https://github.com/vicwomg/pikaraoke/issues/452)) ([405b1f3](https://github.com/vicwomg/pikaraoke/commit/405b1f3984739f7036653659bf15be388727884a))
- allow CLI arg to specify transcode buffer size ([0a6d0bd](https://github.com/vicwomg/pikaraoke/commit/0a6d0bd2ea7fb26c5887737163bcb8678161a12c))
- allow randomized background music from user-specified dir ([a9307f1](https://github.com/vicwomg/pikaraoke/commit/a9307f1d74132905b2ad2d71e26572daf6b254e0))
- background music, score screen, limit queue, stored prefs ([a70d959](https://github.com/vicwomg/pikaraoke/commit/a70d9595f3059c8de4e993070ddf8648ce2fe79f))
- fade volume transition on skip/play/pause [#180](https://github.com/vicwomg/pikaraoke/issues/180) ([2eeb211](https://github.com/vicwomg/pikaraoke/commit/2eeb2110bdda1affce8297e884e15f1cf9bb4555))
- run pikaraoke on a single port ([a523a52](https://github.com/vicwomg/pikaraoke/commit/a523a52ee4e3deb17c14e8f3ffb922d8dcf85c0f))
- support realtime(ish) notifications on splash screen ([823d83d](https://github.com/vicwomg/pikaraoke/commit/823d83d4f408229d7d43cd110e7d9433267959b4))

### Bug Fixes

- alpha bar not showing on files screen ([25cd3d3](https://github.com/vicwomg/pikaraoke/commit/25cd3d3307cf87603a99b42f394eb09a96019c94))
- audit / clean up translations ([1ca27fc](https://github.com/vicwomg/pikaraoke/commit/1ca27fc59e68662c23b06d81f10810766c05e779))
- change buffer_size to be measured in kb ([3ea97cb](https://github.com/vicwomg/pikaraoke/commit/3ea97cbc172d37b4023b27d1e3f8621dca8fb160))
- chunked stream failures on raspberry pi ([#454](https://github.com/vicwomg/pikaraoke/issues/454)) ([8516b4f](https://github.com/vicwomg/pikaraoke/commit/8516b4fb1e3974e9c63f3ac3e88d60ba7bfb452f))
- improve browser warning message ([7469037](https://github.com/vicwomg/pikaraoke/commit/746903745a919f28c501e86fe065f715c3f97d54))
- improve playback loop by using process exit codes ([45bad39](https://github.com/vicwomg/pikaraoke/commit/45bad39711a616eda0c64de193af4ce6d79d8aa5))
- media file path incorrect on windows ([4a38710](https://github.com/vicwomg/pikaraoke/commit/4a38710ac8a2063637c0e840a2a854437448839b))
- song restarts if now_playing status changes during score ([f4140a5](https://github.com/vicwomg/pikaraoke/commit/f4140a51be7eb4e72c4928f6ea347340a70e3094))
- splash menu iframe doesn't load over https ([677576b](https://github.com/vicwomg/pikaraoke/commit/677576b669777bbc74c0d9631a5ff265b8bf8acf))
- support concurrent splash screens [#448](https://github.com/vicwomg/pikaraoke/issues/448) ([#451](https://github.com/vicwomg/pikaraoke/issues/451)) ([5a5d9ea](https://github.com/vicwomg/pikaraoke/commit/5a5d9eac994e660feeda98e38f767c6af631aa78))
- track wont restart while paused ([f716af0](https://github.com/vicwomg/pikaraoke/commit/f716af04806df377b56276f579cf882a17b1c598))

### Performance Improvements

- only transcode files when necessary ([936c3cd](https://github.com/vicwomg/pikaraoke/commit/936c3cd915b7bef76fe33e96cb68aa90a82a1d7d))
- optimize docker build and arg handling ([185f937](https://github.com/vicwomg/pikaraoke/commit/185f9375e2d85daf1e28ea250acffc4c53b62251))

### Documentation

- simplify README, deprecate unused files ([c13ae28](https://github.com/vicwomg/pikaraoke/commit/c13ae28f97d1fafd30c0585bb6bae14836cea6b2))

## [1.7.0](https://github.com/vicwomg/pikaraoke/compare/1.6.1...1.7.0) (2024-12-24)

### Features

- add arm64/amd64 docker builds to release-please ci ([a07265f](https://github.com/vicwomg/pikaraoke/commit/a07265fbece73b49cef95d99dbf54d4a4dd457e3))
- add dockerization support ([f93168f](https://github.com/vicwomg/pikaraoke/commit/f93168fa5413c6cdc20c265934dc05a42c728be2))

### Bug Fixes

- commitlint error ([69cb031](https://github.com/vicwomg/pikaraoke/commit/69cb03170b325a111d4384c150b725f427d23968))
- File was being deleted even if it was in queue ([86dae29](https://github.com/vicwomg/pikaraoke/commit/86dae29b8fb279e5b8a410d22127cf20564359dd))
- Notification not being shown using Flask Flash ([497196a](https://github.com/vicwomg/pikaraoke/commit/497196a78285831492dd7f166f33513d19c29117))
- Transposing hangs when ffmpeg does not have librubberband ([#435](https://github.com/vicwomg/pikaraoke/issues/435)) ([8939e60](https://github.com/vicwomg/pikaraoke/commit/8939e6030aa967a18baf391c8499757708b0a73e))

## [1.6.1](https://github.com/vicwomg/pikaraoke/compare/1.6.0...1.6.1) (2024-12-02)

### Bug Fixes

- prevent hangs when volume change from exceeds max ([#429](https://github.com/vicwomg/pikaraoke/issues/429)) ([d097311](https://github.com/vicwomg/pikaraoke/commit/d0973114be53759f88a59d33112efffc72ebc6db))

## [1.6.0](https://github.com/vicwomg/pikaraoke/compare/1.5.2...1.6.0) (2024-11-23)

### Features

- Added support to Android via Termux App ([#423](https://github.com/vicwomg/pikaraoke/issues/423)) ([0118733](https://github.com/vicwomg/pikaraoke/commit/0118733d698263bc684829aeed69b3c589df43e5))

## [1.5.2](https://github.com/vicwomg/pikaraoke/compare/1.5.1...1.5.2) (2024-11-05)

### Bug Fixes

- admin passwords not working [#401](https://github.com/vicwomg/pikaraoke/issues/401) ([35550dc](https://github.com/vicwomg/pikaraoke/commit/35550dc858864aa928d5f25f75b57472826a11c0))
- broken upgrade path for --break-system-packages users ([9f01f23](https://github.com/vicwomg/pikaraoke/commit/9f01f23ebaabee2aa72b674ebe668d3247be571d))
- broken upgrade path for --break-system-packages users ([#395](https://github.com/vicwomg/pikaraoke/issues/395)) ([74c9dca](https://github.com/vicwomg/pikaraoke/commit/74c9dcaaf2d3a43bf93d4b179c2809be906855b5))
- Italian translation ([#415](https://github.com/vicwomg/pikaraoke/issues/415)) ([2c791c7](https://github.com/vicwomg/pikaraoke/commit/2c791c7f48129f84c9cf45dc2d857ad6742e4c0e))
- support orangepi devices as raspberry pi w/o hw accel ([658d381](https://github.com/vicwomg/pikaraoke/commit/658d381a82b0c87a321ab4f44d6eefea4bfb3bc0))

## [1.5.1](https://github.com/vicwomg/pikaraoke/compare/1.5.0...1.5.1) (2024-09-23)

### Bug Fixes

- 500 error when renaming while queued ([#399](https://github.com/vicwomg/pikaraoke/issues/399)) ([d84fcb3](https://github.com/vicwomg/pikaraoke/commit/d84fcb3ac8974a56e533c2bc3a2c2a58f91baee2))

## [1.5.0](https://github.com/vicwomg/pikaraoke/compare/1.4.1...1.5.0) (2024-09-04)

### Features

- add messages.mo file for es_VE translation ([3cd7d26](https://github.com/vicwomg/pikaraoke/commit/3cd7d2627f1e3ea2d44b482f896f9a6af750b1af))

### Bug Fixes

- song number overflows to add button when &gt; 999 songs [#379](https://github.com/vicwomg/pikaraoke/issues/379) ([a53c9e0](https://github.com/vicwomg/pikaraoke/commit/a53c9e00e144f5203bbecabe1a02f79dff739b68))

### Documentation

- move TROUBLESHOOTING to wiki ([331e814](https://github.com/vicwomg/pikaraoke/commit/331e814a5299189f5248c8595452af5985da3ef4))
- **readme:** recommend Bookworm OS over bullseye ([15598f2](https://github.com/vicwomg/pikaraoke/commit/15598f22e822e3c2014c63a866ecd3b72530698a))

## [1.4.1](https://github.com/vicwomg/pikaraoke/compare/1.4.0...1.4.1) (2024-09-03)

### Bug Fixes

- **ci:** missing long_description in build ([e5482b0](https://github.com/vicwomg/pikaraoke/commit/e5482b036dee906323aed876bed646237be0df5e))

## [1.4.0](https://github.com/vicwomg/pikaraoke/compare/v1.3.0...1.4.0) (2024-09-03)

### Features

- add a setup script ([2d0e973](https://github.com/vicwomg/pikaraoke/commit/2d0e973717892ec072afb0344a969f471e0400e9))
- create python package ([0c97670](https://github.com/vicwomg/pikaraoke/commit/0c97670bea36eb0f8affa17fd23212f64bbed6a7))
- upgrade yt-dlp on all pikaraoke runs ([fedd6ed](https://github.com/vicwomg/pikaraoke/commit/fedd6ed64e53a1e0fec4bc75368e767b57fa6b7e))

### Bug Fixes

- 287 bug: paths with spaces don't work ([f25e326](https://github.com/vicwomg/pikaraoke/commit/f25e32676066754c69f7bfb5b75b54c84ec7d866))
- modify files minimally to make it run ([168abbb](https://github.com/vicwomg/pikaraoke/commit/168abbb069412c1c2913a222623b0bfa0e5ccdf7))
- python-pygame name for apt installation ([be028ab](https://github.com/vicwomg/pikaraoke/commit/be028ab030f3a5a9e6463d9bcbabf6f957ea0dfe))
- resolve issues with commitlint attempt [#1](https://github.com/vicwomg/pikaraoke/issues/1) ([4c375e6](https://github.com/vicwomg/pikaraoke/commit/4c375e665f2333d527335e16d7db6093d96ed5a5))

### Documentation

- add conventional commits badge ([0c63c7d](https://github.com/vicwomg/pikaraoke/commit/0c63c7db4933bfe4549b19b04dc7a46a342039a6))
- rewrite README ([78df2e8](https://github.com/vicwomg/pikaraoke/commit/78df2e8bfc492c75d3befc09b777fdef8d4855fb))
